@@ -10,6 +10,14 @@ test_that("display works", {
       )
     )
   )
+  skip_if_not(
+    isTRUE(
+      tryCatch(
+        fs::dir_exists(rprojroot::find_package_root_file("inst/local-only")),
+        error = function(cnd) FALSE
+      )
+    )
+  )
   img <- read_tif(system.file("img", "Rlogo.tif", package = "ijtiff"))
   vdiffr::expect_doppelganger("raster R logo", display(img, method = "r"))
   vdiffr::expect_doppelganger("basic R logo", display(img, basic = TRUE))
@@ -29,8 +37,8 @@ test_that("display works", {
     "raster R logo (green channel)",
     display(img[, , 3, 1], method = "r")
   )
-  img <- read_tif(system.file("img", "Rlogo-banana-red.tif",
-    package = "ijtiff"
-  ))
+  img <- read_tif(
+    rprojroot::find_package_root_file("inst/local-only/Rlogo-banana-red.tif")
+  )
   vdiffr::expect_doppelganger("R logo banana red", display(img, method = "r"))
 })
